@@ -29,7 +29,7 @@ def before_all():
 
     # Init Tokens JSON data
     # Opening token JSON file
-    f = open(pytest.user_dir + 'testsData/tokens.json')
+    f = open(pytest.user_dir + '/testsData/tokens.json')
     # Returns JSON object as a dictionary
     tokens = json.load(f)
     # Store the data in pytest global variables
@@ -39,7 +39,7 @@ def before_all():
 
     # Init farms JSON data
     # Opening farms JSON file
-    f = open(pytest.user_dir + 'testsData/farms.json')
+    f = open(pytest.user_dir + '/testsData/farms.json')
     # Returns JSON object as a dictionary
     farms_data = json.load(f)
     # Store the data in pytest global variables
@@ -49,7 +49,7 @@ def before_all():
 
     # Init wallets JSON data
     # Opening wallets JSON file
-    f = open(pytest.user_dir + 'testsData/wallets.json')
+    f = open(pytest.user_dir + '/testsData/wallets.json')
     # Returns JSON object as a dictionary
     wallets_data = json.load(f)
     # Store the data in pytest global variables
@@ -58,7 +58,7 @@ def before_all():
     f.close()
 
     # Initialize the logger instance.
-    with open(pytest.user_dir + 'Tests/logging.yaml', 'rt') as f:
+    with open(pytest.user_dir + '/Tests/logging.yaml', 'rt') as f:
         config = yaml.safe_load(f.read())
     logging.config.dictConfig(config)
 
